@@ -175,6 +175,17 @@ def create_task(coro):
 
     return task
 
+async def await_bg_tasks(timeout=None):
+
+    if not bgtasks:
+        return []
+
+    coro = asyncio.gather(*tuple(bgtasks), return_exceptions=True)
+    try:
+        return await s_common.wait_for(coro, timeout)
+    except (asyncio.CancelledError, asyncio.TimeoutError):
+        return []
+
 class GenrHelp:
 
     def __init__(self, genr):
