@@ -2,11 +2,13 @@
 Module which implements the synapse module API/convention.
 '''
 coremods = (
+    'synapse.models.doc.DocModule',
     'synapse.models.dns.DnsModule',
     'synapse.models.orgs.OuModule',
     'synapse.models.syn.SynModule',
     'synapse.models.auth.AuthModule',
     'synapse.models.base.BaseModule',
+    'synapse.models.math.MathModule',
     'synapse.models.risk.RiskModule',
     'synapse.models.person.PsModule',
     'synapse.models.files.FileModule',
@@ -17,6 +19,7 @@ coremods = (
     'synapse.models.telco.TelcoModule',
     'synapse.models.inet.InetModule',
     'synapse.models.material.MatModule',
+    'synapse.models.entity.EntityModule',
     'synapse.models.language.LangModule',
     'synapse.models.crypto.CryptoModule',
     'synapse.models.gov.cn.GovCnModule',
@@ -26,4 +29,7 @@ coremods = (
     'synapse.models.transport.TransportModule',
     'synapse.models.proj.ProjectModule',
     'synapse.models.biz.BizModule',
+    'synapse.models.belief.BeliefModule',
+    'synapse.models.science.ScienceModule',
+    'synapse.models.planning.PlanModule',
 )
