@@ -24,6 +24,22 @@ ipaddress = s_common.ipaddress
 
 logger = logging.getLogger(__name__)
 
+urilist = set(s_data.get('iana.uris'))
+urilist.update([
+    'aha',
+    'ftps',
+    'mysql',
+    'postgresql',
+    'slack',
+    'socks4',
+    'socks4a',
+    'socks5',
+    'socks5h',
+    'tcp',
+    'unk',
+    'webpack'
+])
+
 tldlist = list(s_data.get('iana.tlds'))
 tldlist.extend([
     'bit',
@@ -49,22 +65,12 @@ inverse_prefixs = {
     '<': '>',
     '{': '}',
     '(': ')',
+    '\u2018': '\u2019',  # Unicode Left Single Quotation Mark and Right Single Quotation Mark
+    '\u201c': '\u201d',  # Unicode Left Double Quotation Mark and Right Double Quotation Mark
 }
 
 cve_dashes = ''.join(('-',) + s_chop.unicode_dashes)
 
-def fqdn_prefix_check(match: regex.Match):
-    mnfo = match.groupdict()
-    valu = mnfo.get('valu')
-    prefix = mnfo.get('prefix')
-    cbfo = {}
-    if prefix is not None:
-        new_valu = valu.rstrip(inverse_prefixs.get(prefix))
-        if new_valu != valu:
-            valu = new_valu
-            cbfo['match'] = valu
-    return valu, cbfo
-
 def fqdn_check(match: regex.Match):
     mnfo = match.groupdict()
     valu = mnfo.get('valu')
@@ -128,6 +134,8 @@ _cpe23_regex = r'''(?P<valu>cpe:2\.3:[aho\*-]
 (?::(([?]+|\*)?([a-z0-9-._]|\\[\\?*!"#$%&\'()+,/:;<=>@\[\]^`{|}~])+([?]+|\*)?|[*-])){4})
 '''
 
+path_parts_limit = 1024
+
 linux_path_regex = r'''
 (?<![\w\d]+)
 (?P<valu>
@@ -142,17 +150,23 @@ linux_path_rootdirs = (
     'sys', 'tmp', 'usr', 'var'
 )
 
+# https://docs.kernel.org/filesystems/path-lookup.html#the-symlink-stack
+linux_path_limit = 4096
+
 def linux_path_check(match: regex.Match):
     mnfo = match.groupdict()
     valu = mnfo.get('valu')
 
+    if len(valu) > linux_path_limit:
+        return None, {}
+
     path = pathlib.PurePosixPath(valu)
     parts = path.parts
 
     if parts[0] != '/':
         return None, {}
 
-    if len(parts) < 2:
+    if len(parts) < 2 or len(parts) > path_parts_limit:
         return None, {}
 
     if parts[1] not in linux_path_rootdirs:
@@ -177,17 +191,26 @@ windows_path_reserved = (
 
 windows_drive_paths = [f'{letter}:\\' for letter in string.ascii_lowercase]
 
+# https://learn.microsoft.com/en-us/windows/win32/fileio/maximum-file-path-limitation
+windows_path_limit = 32_767
+
 # https://learn.microsoft.com/en-us/windows/win32/fileio/naming-a-file#naming-conventions
 def windows_path_check(match: regex.Match):
     mnfo = match.groupdict()
     valu = mnfo.get('valu')
 
+    if len(valu) > windows_path_limit:
+        return None, {}
+
     path = pathlib.PureWindowsPath(valu)
     parts = path.parts
 
     if parts[0].lower() not in windows_drive_paths:
         return None, {}
 
+    if len(parts) > path_parts_limit:
+        return None, {}
+
     for part in parts:
         if part in windows_path_reserved:
             return None, {}
@@ -244,12 +267,30 @@ def unc_path_check(match: regex.Match):
 
     return valu, {}
 
+def url_scheme_check(match: regex.Match):
+    mnfo = match.groupdict()
+    valu = mnfo.get('valu')
+    prefix = mnfo.get('prefix')
+
+    cbfo = {}
+    if prefix is not None:
+        new_valu = valu.rstrip(inverse_prefixs.get(prefix))
+        if new_valu != valu:
+            valu = new_valu
+            cbfo['match'] = valu
+
+    scheme = valu.split('://')[0].lower()
+    if scheme not in urilist:
+        return None, {}
+
+    return valu, cbfo
+
 # these must be ordered from most specific to least specific to allow first=True to work
 scrape_types = [  # type: ignore
     ('file:path', linux_path_regex, {'callback': linux_path_check, 'flags': regex.VERBOSE}),
     ('file:path', windows_path_regex, {'callback': windows_path_check, 'flags': regex.VERBOSE}),
-    ('inet:url', r'(?P<prefix>[\\{<\(\[]?)(?P<valu>[a-zA-Z][a-zA-Z0-9]*://(?(?=[,.]+[ \'\"\t\n\r\f\v])|[^ \'\"\t\n\r\f\v])+)',
-     {'callback': fqdn_prefix_check}),
+    ('inet:url', r'(?P<prefix>[‘“\\{<\(\[]?)(?P<valu>[a-zA-Z][a-zA-Z0-9]*://(?(?=[,.]+[ \'\"\t\n\r\f\v])|[^ \'\"\t\n\r\f\v])+)',
+     {'callback': url_scheme_check}),
     ('inet:url', r'(["\'])?(?P<valu>\\[^\n]+?)(?(1)\1|\s)', {'callback': unc_path_check}),
     ('inet:email', r'(?=(?:[^a-z0-9_.+-]|^)(?P<valu>[a-z0-9_\.\-+]{1,256}@(?:[a-z0-9_-]{1,63}\.){1,10}(?:%s))(?:[^a-z0-9_.-]|[.\s]|$))' % tldcat, {}),
     ('inet:server', fr'(?P<valu>(?:(?<!\d|\d\.|[0-9a-f:]:)((?P<addr>{ipv4_match})|\[(?P<v6addr>{ipv6_match})\]):(?P<port>\d{{1,5}})(?!\d|\.\d)))',
