@@ -55,8 +55,9 @@ TerminalPygMap = {
     'LSQB': p_t.Punctuation,
     'MCASEBARE': p_t.Literal.String,
     'MODSET': p_t.Operator,
+    'MODSETMULTI': p_t.Operator,
     'NONQUOTEWORD': p_t.Literal,
-    'NOT': p_t.Keyword,
+    'NOTOP': p_t.Operator,
     'NULL': p_t.Keyword,
     'NUMBER': p_t.Literal.Number,
     'OCTNUMBER': p_t.Literal.Number,
@@ -74,9 +75,10 @@ TerminalPygMap = {
     'TAGSEGNOVAR': p_t.Name,
     'TRIPLEQUOTEDSTRING': p_t.Literal.String,
     'TRYSET': p_t.Operator,
-    'TRYSETMINUS': p_t.Operator,
-    'TRYSETPLUS': p_t.Operator,
+    'TRYMODSET': p_t.Operator,
+    'TRYMODSETMULTI': p_t.Operator,
     'UNIVNAME': p_t.Name,
+    'UNSET': p_t.Operator,
     'EXPRUNIVNAME': p_t.Name,
     'VARTOKN': p_t.Name.Variable,
     'EXPRVARTOKN': p_t.Name.Variable,
@@ -113,6 +115,7 @@ TerminalPygMap = {
     '_LPARNOSPACE': p_t.Punctuation,
     '_MATCHHASH': p_t.Punctuation,
     '_MATCHHASHWILD': p_t.Punctuation,
+    '_NOT': p_t.Keyword,
     '_RETURN': p_t.Keyword,
     '_REVERSE': p_t.Keyword,
     '_RIGHTJOIN': p_t.Punctuation,
