@@ -270,7 +270,7 @@ class FileModule(s_module.CoreModule):
                         ('file', ('file:bytes', {}), {
                             'doc': 'The Mach-O file containing the load command.'}),
                         ('type', ('int', {'enums': s_l_macho.getLoadCmdTypes()}), {
-                            'doc': 'The type of the load command'}),
+                            'doc': 'The type of the load command.'}),
                         ('size', ('int', {}), {
                             'doc': 'The size of the load command structure in bytes.'}),
                     ),
@@ -724,7 +724,7 @@ class FileModule(s_module.CoreModule):
                     ('sha256', ('hash:sha256', {}), {
                         'doc': 'The sha256 hash of the bytes of the Mach-O section.'}),
                     ('offset', ('int', {}), {
-                        'doc': 'The file offset to the beginning of the section'}),
+                        'doc': 'The file offset to the beginning of the section.'}),
                 )),
 
                 ('file:mime:lnk', {}, (
