@@ -31,6 +31,8 @@ televers = (3, 0)
 
 aha_clients = {}
 
+LINK_CULL_INTERVAL = 10
+
 async def addAhaUrl(url):
     '''
     Add (incref) an aha registry URL.
@@ -321,6 +323,9 @@ class Aware:
         '''
         return self
 
+    async def getTeleFeats(self):
+        return {}
+
     def onTeleShare(self, dmon, name):
         pass
 
@@ -389,7 +394,7 @@ class Share(s_base.Base):
             This should never be used by synapse core code.  This is for sync client code convenience only.
         '''
         if s_threads.iden() == self.tid:
-            raise s_exc.SynErr('Use of synchronous context manager in async code')
+            raise s_exc.SynErr(mesg='Use of synchronous context manager in async code')
 
         self._ctxobj = self.schedCoroSafePend(self.__aenter__())
         return self
@@ -587,6 +592,10 @@ class Proxy(s_base.Base):
         valu = proxy.getFooValu(x, y)
 
     '''
+    _link_task = None
+    _link_event = None
+    _all_proxies = set()
+
     async def __anit__(self, link, name):
 
         await s_base.Base.__anit__(self)
@@ -599,15 +608,21 @@ class Proxy(s_base.Base):
         self.shares = {}
 
         self._ahainfo = {}
+        self._features = {}
+
         self.sharinfo = {}
         self.methinfo = {}
 
         self.sess = None
+
         self.links = collections.deque()
-        self._link_poolsize = 4
+        self.alllinks = collections.deque()
+
+        self._link_add = 0      # counter for pending links being connected
+        self._links_min = 4     # low water mark for the link pool
+        self._links_max = 12    # high water mark for the link pool
 
         self.synack = None
-        self.syndone = asyncio.Event()
 
         self.handlers = {
             'task:fini': self._onTaskFini,
@@ -621,19 +636,60 @@ class Proxy(s_base.Base):
                 await item.fini()
 
             mesg = ('task:fini', {'retn': (False, ('IsFini', {}))})
-            for name, task in list(self.tasks.items()):
+            for iden, task in list(self.tasks.items()):  # pragma: no cover
                 task.reply(mesg)
-                del self.tasks[name]
+                del self.tasks[iden]
 
-            for link in self.links:
-                await link.fini()
+            # fini all the links from a different task to prevent
+            # delaying the proxy shutdown...
+            s_coro.create_task(self._finiAllLinks())
 
-            del self.syndone
-            await self.link.fini()
+            if self in self._all_proxies:
+                self._all_proxies.remove(self)
+
+            if not Proxy._all_proxies and Proxy._link_task is not None:
+                Proxy._link_task.cancel()
+                Proxy._link_task = None
+                Proxy._link_event = None
+
+        Proxy._all_proxies.add(self)
 
         self.onfini(fini)
         self.link.onfini(self.fini)
 
+        if Proxy._link_task is None:
+            Proxy._link_event = asyncio.Event()
+            Proxy._link_task = s_coro.create_task(Proxy._linkLoopTask())
+
+    @classmethod
+    async def _linkLoopTask(clas):
+        while True:
+            try:
+                await s_coro.event_wait(Proxy._link_event, timeout=LINK_CULL_INTERVAL)
+
+                for proxy in list(Proxy._all_proxies):
+
+                    if proxy.isfini:
+                        continue
+
+                    # close one link per proxy per period if the number of
+                    # available links is greater than _links_max...
+                    if len(proxy.links) > proxy._links_max:
+                        link = proxy.links.popleft()
+                        await link.fini()
+                        await proxy.fire('pool:link:fini', link=link)
+
+                Proxy._link_event.clear()
+
+            except Exception:  # pragma: no cover
+                logger.exception('synapse.telepath.Proxy.linkLoopTask()')
+
+    def _hasTeleFeat(self, name, vers=1):
+        return self._features.get(name, 0) >= vers
+
+    def _hasTeleMeth(self, name):
+        return self.methinfo.get(name) is not None
+
     def _getSynVers(self):
         '''
         Helper method to retrieve the remote Synapse version from Proxy.
@@ -681,6 +737,12 @@ class Proxy(s_base.Base):
 
             link = self.links.popleft()
 
+            # fire a task to replace the link if we are
+            # below the low-water mark for link count.
+            if len(self.links) + self._link_add < self._links_min:
+                self._link_add += 1
+                self.schedCoro(self._addPoolLink())
+
             if link.isfini:
                 continue
 
@@ -689,6 +751,11 @@ class Proxy(s_base.Base):
         # we need a new one...
         return await self._initPoolLink()
 
+    async def _addPoolLink(self):
+        link = await self._initPoolLink()
+        self.links.append(link)
+        self._link_add -= 1
+
     async def getPipeline(self, genr, name=None):
         '''
         Construct a proxy API call pipeline in order to make
@@ -713,8 +780,6 @@ class Proxy(s_base.Base):
 
     async def _initPoolLink(self):
 
-        # TODO loop / backoff
-
         if self.link.get('unix'):
 
             path = self.link.get('path')
@@ -728,19 +793,26 @@ class Proxy(s_base.Base):
 
             link = await s_link.connect(host, port, ssl=ssl)
 
-        self.onfini(link)
+        self.alllinks.append(link)
+        async def fini():
+            self.alllinks.remove(link)
+            if link in self.links:
+                self.links.remove(link)
+
+        link.onfini(fini)
 
         return link
 
+    async def _finiAllLinks(self):
+        for link in list(self.alllinks):
+            await link.fini()
+        await self.link.fini()
+
     async def _putPoolLink(self, link):
 
         if link.isfini:
             return
 
-        # If we've exceeded our poolsize, discard the current link.
-        if len(self.links) >= self._link_poolsize:
-            return await link.fini()
-
         self.links.append(link)
 
     def __enter__(self):
@@ -751,7 +823,7 @@ class Proxy(s_base.Base):
             This must not be used from async code, and it should never be used in core synapse code.
         '''
         if s_threads.iden() == self.tid:
-            raise s_exc.SynErr('Use of synchronous context manager in async code')
+            raise s_exc.SynErr(mesg='Use of synchronous context manager in async code')
         self._ctxobj = self.schedCoroSafePend(self.__aenter__())
         return self
 
@@ -851,6 +923,7 @@ class Proxy(s_base.Base):
 
                 except GeneratorExit:
                     # if they bail early on the genr, fini the link
+                    # TODO: devise a tx/rx strategy to recover these links...
                     await link.fini()
 
             return s_coro.GenrHelp(genrloop())
@@ -906,6 +979,7 @@ class Proxy(s_base.Base):
 
         self.sess = self.synack[1].get('sess')
         self._ahainfo = self.synack[1].get('ahainfo', {})
+        self._features = self.synack[1].get('features', {})
         self.sharinfo = self.synack[1].get('sharinfo', {})
         self.methinfo = self.sharinfo.get('meths', {})
 
@@ -1309,7 +1383,6 @@ class Client(s_base.Base):
         info.update(self._t_opts)
         self._t_proxy = await openinfo(info)
         self._t_methinfo = self._t_proxy.methinfo
-        self._t_proxy._link_poolsize = self._t_conf.get('link_poolsize', 4)
 
         async def fini():
             if self._t_named_meths:
@@ -1532,8 +1605,6 @@ async def openinfo(info):
         # cell://rel/path/to/celldir:share
         path = info.get('path')
 
-        name = info.get('name', '*')
-
         # support cell://<relpath>/<to>/<cell>
         # by detecting host...
         host = info.get('host')
@@ -1541,9 +1612,12 @@ async def openinfo(info):
             path = path.strip('/')
             path = os.path.join(host, path)
 
+        name = '*'
         if ':' in path:
             path, name = path.split(':')
 
+        name = info.get('name', name)
+
         full = os.path.join(path, 'sock')
         link = await s_link.unixconnect(full)
 
@@ -1553,6 +1627,7 @@ async def openinfo(info):
         path = info.get('path')
         if ':' in path:
             path, name = path.split(':')
+        name = info.get('name', name)
         link = await s_link.unixconnect(path)
 
     elif scheme in ('tcp', 'ssl'):
