@@ -203,6 +203,10 @@ A bunch of prefixed urls
 
 https://c2server.com/evil/malware/doesnot[care+]aboutstandards{at-all}
 
+beep “https://unicode.doublequote.org/test.php” boop
+
+x ‘https://unicode.singlequote.org/test.php’ z
+
 '''
 
 data3 = '''
@@ -446,6 +450,10 @@ var/run/foo/
 var/run/foo/bar
 but they not have a open SDK :/.
 '''
+linux_paths += '\n' + '\n'.join([
+    '/bin' + '/long' * 1_024,
+    '/bin' + '/a' * 1_024,
+])
 
 windows_paths = '''
 # GOOD PATHS
@@ -472,6 +480,10 @@ c:\\windows\\LPT1
 c:\\foo.
 dc:\\foo\\bar
 '''
+windows_paths += '\n' + '\n'.join([
+    'c:\\windows' + '\\long' * 7_000,
+    'c:\\windows' + '\\a' * 1_024,
+])
 
 good_uncs = [
     '\\\\foo\\bar\\baz',
@@ -717,6 +729,8 @@ class ScrapeTest(s_t_utils.SynTest):
         nodes.remove(('inet:url', 'https://www.thingspace.com/blog/giggles.html'))
         nodes.remove(('inet:url', 'https://testme.org/test.php'))
         nodes.remove(('inet:url', 'https://c2server.com/evil/malware/doesnot[care+]aboutstandards{at-all}'))
+        nodes.remove(('inet:url', 'https://unicode.doublequote.org/test.php'))
+        nodes.remove(('inet:url', 'https://unicode.singlequote.org/test.php'))
 
         nodes = list(s_scrape.scrape(btc_addresses))
         self.len(11, nodes)
@@ -1179,3 +1193,53 @@ class ScrapeTest(s_t_utils.SynTest):
         nodes.remove(('it:sec:cpe', 'cpe:2.3:*:*why*:*:*:*:*:*:*:*:*:*'))
 
         self.len(0, nodes)
+
+    def test_scrape_uris(self):
+
+        nodes = list(s_scrape.scrape('http://vertex.link https://woot.com'))
+        self.len(4, nodes)
+        self.isin(('inet:url', 'http://vertex.link'), nodes)
+        self.isin(('inet:url', 'https://woot.com'), nodes)
+        self.isin(('inet:fqdn', 'vertex.link'), nodes)
+        self.isin(('inet:fqdn', 'woot.com'), nodes)
+
+        nodes = list(s_scrape.scrape('ftps://files.vertex.link tcp://1.2.3.4:8080'))
+        self.len(5, nodes)
+        self.isin(('inet:url', 'ftps://files.vertex.link'), nodes)
+        self.isin(('inet:url', 'tcp://1.2.3.4:8080'), nodes)
+        self.isin(('inet:fqdn', 'files.vertex.link'), nodes)
+        self.isin(('inet:ipv4', '1.2.3.4'), nodes)
+        self.isin(('inet:server', '1.2.3.4:8080'), nodes)
+
+        nodes = list(s_scrape.scrape('invalidscheme://vertex.link newp://woot.com'))
+        self.len(2, nodes)
+        self.isin(('inet:fqdn', 'vertex.link'), nodes)
+        self.isin(('inet:fqdn', 'woot.com'), nodes)
+
+        nodes = list(s_scrape.scrape('[https://vertex.link] (http://woot.com)'))
+        self.len(4, nodes)
+        self.isin(('inet:url', 'https://vertex.link'), nodes)
+        self.isin(('inet:url', 'http://woot.com'), nodes)
+        self.isin(('inet:fqdn', 'vertex.link'), nodes)
+        self.isin(('inet:fqdn', 'woot.com'), nodes)
+
+        nodes = list(s_scrape.scrape('HTTP://vertex.link HTTPS://woot.com'))
+        self.len(4, nodes)
+        self.isin(('inet:url', 'HTTP://vertex.link'), nodes)
+        self.isin(('inet:url', 'HTTPS://woot.com'), nodes)
+        self.isin(('inet:fqdn', 'vertex.link'), nodes)
+        self.isin(('inet:fqdn', 'woot.com'), nodes)
+
+        nodes = list(s_scrape.scrape('hxxps://vertex[.]link hXXp://woot[.]com'))
+        self.len(4, nodes)
+        self.isin(('inet:url', 'https://vertex.link'), nodes)
+        self.isin(('inet:url', 'http://woot.com'), nodes)
+        self.isin(('inet:fqdn', 'vertex.link'), nodes)
+        self.isin(('inet:fqdn', 'woot.com'), nodes)
+
+        nodes = list(s_scrape.scrape('hxxp[:]//vertex(.)link hXXps[://]woot[.]com'))
+        self.len(4, nodes)
+        self.isin(('inet:url', 'http://vertex.link'), nodes)
+        self.isin(('inet:url', 'https://woot.com'), nodes)
+        self.isin(('inet:fqdn', 'vertex.link'), nodes)
+        self.isin(('inet:fqdn', 'woot.com'), nodes)
