@@ -310,6 +310,42 @@ class ViewTest(s_t_utils.SynTest):
             # But not the same layer twice
             await self.asyncraises(s_exc.DupIden, core.view.addLayer(layriden))
 
+            # Nodes with a large number of edge edits may be chunked by iterLayerNodeEdits
+            await core.nodes('[ test:str=foo ] for $i in $lib.range(102) {[ test:int=$i ]}')
+
+            vdef2 = await core.view.fork()
+            opts = {'view': vdef2['iden']}
+            await core.nodes('[ test:str=foo +(refs)> { for $i in $lib.range(102) { test:int=$i } } ]', opts=opts)
+
+            strt = core.nexsroot.nexslog.index()
+            await core.nodes('$lib.view.get().merge()', opts=opts)
+
+            self.len(102, await core.nodes('test:str=foo -(refs)> test:int'))
+
+            edits = [edit async for edit in core.nexsroot.nexslog.iter(strt)]
+            self.len(1, edits)
+
+            nodeedit = edits[0][1][2][0]
+
+            # We should have two chunks of edits for the same buid due to the number of edges
+            self.eq(nodeedit[0][0], nodeedit[1][0])
+            self.len(100, nodeedit[0][2])
+            self.len(2, nodeedit[1][2])
+
+            await core.nodes('[ test:str=lowertag +#a.b=2020]')
+
+            vdef2 = await core.view.fork()
+            opts = {'view': vdef2['iden']}
+            await core.nodes('test:str=lowertag [ +#a.b.c ]', opts=opts)
+
+            retn = await core.callStorm('test:str=lowertag return($node.getStorNodes())', opts=opts)
+
+            # Only leaf tag is added in our top layer
+            self.isin('a.b.c', retn[0].get('tags'))
+            self.notin('a.b', retn[0].get('tags'))
+
+            self.isin('a.b', retn[1].get('tags'))
+
     async def test_view_merge_ival(self):
 
         async with self.getTestCore() as core:
@@ -547,7 +583,7 @@ class ViewTest(s_t_utils.SynTest):
             await core.nodes('inet:ipv4=0 | delnode')
 
             edits = await core.callStorm('''
-                $nodeedits = $lib.list()
+                $nodeedits = ()
                 for ($offs, $edits) in $lib.layer.get().edits(wait=$lib.false) {
                     $nodeedits.extend($edits)
                 }
@@ -689,7 +725,7 @@ class ViewTest(s_t_utils.SynTest):
                 puller_iden, puller_view, puller_layr = await core2.callStorm('''
                     $lyr = $lib.layer.add()
                     $view = $lib.view.add(($lyr.iden,))
-                    $pdef = $lyr.addPull($lib.str.concat($baseurl, "/", $baseiden))
+                    $pdef = $lyr.addPull(`{$baseurl}/{$baseiden}`)
                     return(($pdef.iden, $view.iden, $lyr.iden))
                 ''', opts=opts)
 
@@ -707,7 +743,7 @@ class ViewTest(s_t_utils.SynTest):
                 opts['vars']['pushiden'] = pushee_layr
                 pushee_iden = await core.callStorm('''
                     $lyr = $lib.layer.get()
-                    $pdef = $lyr.addPush($lib.str.concat($syncurl, "/", $pushiden))
+                    $pdef = $lyr.addPush(`{$syncurl}/{$pushiden}`)
                     return($pdef.iden)
                 ''', opts=opts)
 
@@ -717,7 +753,7 @@ class ViewTest(s_t_utils.SynTest):
 
                 mirror_catchup = await core2.getNexsIndx() - 1 + 2 + layr.nodeeditlog.size
                 mirror_view, mirror_layr = await core2.callStorm('''
-                    $ldef = ({'mirror':$lib.str.concat($baseurl, "/", $baseiden)})
+                    $ldef = ({'mirror': `{$baseurl}/{$baseiden}`})
                     $lyr = $lib.layer.add(ldef=$ldef)
                     $view = $lib.view.add(($lyr.iden,))
                     return(($view.iden, $lyr.iden))
@@ -906,6 +942,14 @@ class ViewTest(s_t_utils.SynTest):
             with self.raises(s_exc.BadState):
                 await core.callStorm('return($lib.view.get().insertParentFork().iden)')
 
+            pname = view01.parent.info.get('name')
+            vdef = await view01.insertParentFork(visi.iden)
+            self.eq(vdef.get('name'), f'inserted fork of {pname}')
+
+            piden = view03.parent.iden
+            vdef = await view03.insertParentFork(visi.iden)
+            self.eq(vdef.get('name'), f'inserted fork of {piden}')
+
     async def test_view_children(self):
 
         async with self.getTestCore() as core:
