@@ -63,6 +63,18 @@ class SynModelTest(s_t_utils.SynTest):
 
             self.eq('root', await core.callStorm(f'return($lib.repr(syn:user, {iden}))'))
 
+            with self.raises(s_exc.BadTypeValu) as exc:
+                await core.callStorm('return($lib.cast(syn:user, newp))')
+            self.eq(exc.exception.get('mesg'), 'No user named newp and value is not a guid.')
+            self.eq(exc.exception.get('valu'), 'newp')
+            self.eq(exc.exception.get('name'), 'syn:user')
+
+            with self.raises(s_exc.BadTypeValu) as exc:
+                await core.callStorm('[ it:exec:query=* :synuser=* ]')
+            self.isin('syn:user values must be a valid username or a guid.', exc.exception.get('mesg'))
+            self.eq(exc.exception.get('valu'), '*')
+            self.eq(exc.exception.get('name'), 'syn:user')
+
             (ok, iden) = await core.callStorm('return($lib.trycast(syn:role, all))')
             self.true(ok)
             self.eq(iden, core.auth.allrole.iden)
@@ -74,6 +86,18 @@ class SynModelTest(s_t_utils.SynTest):
 
             self.eq('all', await core.callStorm(f'return($lib.repr(syn:role, {iden}))'))
 
+            with self.raises(s_exc.BadTypeValu) as exc:
+                await core.callStorm('return($lib.cast(syn:role, newp))')
+            self.eq(exc.exception.get('mesg'), 'No role named newp and value is not a guid.')
+            self.eq(exc.exception.get('valu'), 'newp')
+            self.eq(exc.exception.get('name'), 'syn:role')
+
+            with self.raises(s_exc.BadTypeValu) as exc:
+                await core.callStorm('$lib.cast(syn:role, *)')
+            self.eq(exc.exception.get('mesg'), 'syn:role values must be a valid rolename or a guid.')
+            self.eq(exc.exception.get('valu'), '*')
+            self.eq(exc.exception.get('name'), 'syn:role')
+
             # coverage for DataModel without a cortex reference
             iden = s_common.guid()
 
@@ -89,6 +113,40 @@ class SynModelTest(s_t_utils.SynTest):
             self.eq(iden, synuser.norm(iden)[0])
             self.eq(iden, synrole.norm(iden)[0])
 
+    async def test_synuser_merge_failure(self):
+        async with self.getTestCore() as core:
+
+            visi = await core.addUser('visi')
+            view = await core.callStorm('return($lib.view.get().fork().iden)')
+
+            q = '[proj:project=(p1,) :creator=visi ]'
+            msgs = await core.stormlist(q, opts={'view': view})
+            self.stormHasNoWarnErr(msgs)
+
+            q = 'proj:project=(p1,)'
+            msgs = await core.stormlist(q, opts={'view': view, 'repr': True})
+            self.stormHasNoWarnErr(msgs)
+
+            await core.delUser(visi.get('iden'))
+
+            q = 'proj:project=(p1,)'
+            msgs = await core.stormlist(q, opts={'view': view, 'repr': True})
+            self.stormHasNoWarnErr(msgs)
+
+            # this works
+            q = '$lib.view.get($view).merge()'
+            msgs = await core.stormlist(q, opts={'vars': {'view': view}})
+            self.stormHasNoWarnErr(msgs)
+
+            # this fails
+            q = 'proj:project | merge --apply'
+            msgs = await core.stormlist(q, opts={'view': view, 'repr': True})
+            self.stormHasNoWarnErr(msgs)
+
+            q = 'proj:project=(p1,)'
+            msgs = await core.stormlist(q, opts={'vars': {'view': view}})
+            self.stormHasNoWarnErr(msgs)
+
     async def test_syn_tag(self):
 
         async with self.getTestCore() as core:
@@ -612,10 +670,16 @@ class SynModelTest(s_t_utils.SynTest):
                 nodes = await core.nodes('syn:cmd +:package')
                 self.len(0, nodes)
 
-                await core.nodes(f'service.add test {url}')
-                iden = core.getStormSvcs()[0].iden
+                with self.getLoggerStream('synapse.cortex') as stream:
+                    await core.nodes(f'service.add test {url}')
+                    iden = core.getStormSvcs()[0].iden
 
-                await core.nodes('$lib.service.wait(test)')
+                    await core.nodes('$lib.service.wait(test)')
+
+                stream.seek(0)
+                warn = "Storm command definition 'forms' key is deprecated and will be removed " \
+                       "in 3.0.0 (command foobar in package foo)"
+                self.isin(warn, stream.read())
 
                 # check that runt nodes for new commands are created
                 nodes = await core.nodes('syn:cmd +:package')
