@@ -1,17 +1,16 @@
 import os
 import ssl
-import json
+import sys
 import socket
 import asyncio
 import logging
-import threading
+import multiprocessing
 
 from unittest import mock
 
 import cryptography.hazmat.primitives.hashes as c_hashes
 
 import synapse.exc as s_exc
-import synapse.glob as s_glob
 import synapse.common as s_common
 import synapse.daemon as s_daemon
 import synapse.telepath as s_telepath
@@ -19,6 +18,7 @@ import synapse.telepath as s_telepath
 import synapse.lib.cell as s_cell
 import synapse.lib.coro as s_coro
 import synapse.lib.link as s_link
+import synapse.lib.const as s_const
 import synapse.lib.share as s_share
 import synapse.lib.certdir as s_certdir
 import synapse.lib.version as s_version
@@ -53,6 +53,9 @@ class Beep:
     def beep(self):
         return f'{self.path}: beep'
 
+    def genbeep(self):
+        yield self.beep()
+
 class Foo:
 
     def __init__(self):
@@ -68,6 +71,10 @@ class Foo:
     def echo(self, x):
         return x
 
+    def echosize(self, array: list[bytes]):
+        total = sum([len(bytz) for bytz in array])
+        return total
+
     def speed(self):
         return
 
@@ -103,7 +110,7 @@ class Foo:
 
     def raze(self):
         # test that SynErr makes it through
-        raise s_exc.NoSuchMeth(name='haha')
+        raise s_exc.SynErr(mesg='hehe', key='valu')
 
     async def corovalu(self, x, y):
         return x * 2 + y
@@ -133,6 +140,9 @@ class TeleApi:
     def getFooBar(self, x, y):
         return x - y
 
+    def genGetFooBar(self, x, y):
+        yield self.getFooBar(x, y)
+
     async def customshare(self):
         return await CustomShare.anit(self.link, 42)
 
@@ -155,6 +165,11 @@ class TeleAware(s_telepath.Aware):
 
         return self._initBeep(path[0])
 
+    async def getTeleFeats(self):
+        return {
+            'aware': 1,
+        }
+
 class TeleAuth(s_telepath.Aware):
 
     def getTeleApi(self, link, mesg, path):
@@ -174,6 +189,40 @@ class TeleAuth(s_telepath.Aware):
     def getFooBar(self, x, y):
         return x + y
 
+def run_telepath_sync_genr_break(url: str,
+                      evt1: multiprocessing.Event,
+                      evt2: multiprocessing.Event,):
+    '''
+    This is a Process target.
+    '''
+    with s_telepath.openurl(url) as prox:
+        form = 'test:int'
+
+        q = '[' + ' '.join([f'{form}={i}' for i in range(10)]) + ' ]'
+
+        # This puts a link into the link pool
+        emesg = 12
+        msgs = list(prox.storm(q, opts={'show': ('node', 'nodeedits')}))
+        assert len(msgs) == emesg, f'Got {len(msgs)} messages, expected {emesg}'
+
+        # Get the link from the pool, add the fini callback and put it back
+        # This involves reaching into the proxy internals to do so.
+        link = prox.links.popleft()
+        link.onfini(evt1.set)
+        prox.links.append(link)
+
+        # Break from the generator right away, causing a
+        # GeneratorExit in the GenrHelp object __iter__ method.
+        mesg = None
+        for mesg in prox.storm(q):
+            break
+        # Ensure the query did yield an object
+        assert mesg is not None, 'mesg was not recieved!'
+        assert link.isfini is True, 'link.fini was not set to true'
+
+        evt2.set()
+        sys.exit(137)
+
 class TeleTest(s_t_utils.SynTest):
 
     async def test_telepath_basics(self):
@@ -230,11 +279,13 @@ class TeleTest(s_t_utils.SynTest):
             # Add an additional prox.fini handler.
             prox.onfini(evt.set)
 
-            # check a standard return value
-            self.eq(30, await prox.bar(10, 20))
+            with mock.patch('synapse.lib.link.MAXWRITE', 2):
 
-            # check a coroutine return value
-            self.eq(25, await prox.corovalu(10, 5))
+                # check a standard return value
+                self.eq(30, await prox.bar(10, 20))
+
+                # check a coroutine return value
+                self.eq(25, await prox.corovalu(10, 5))
 
             # check a generator return channel
             genr = await prox.genr()
@@ -254,17 +305,48 @@ class TeleTest(s_t_utils.SynTest):
             genr = prox.agenrboom()
             await self.asyncraises(s_exc.SynErr, genr.list())
 
-            await self.asyncraises(s_exc.NoSuchMeth, prox.raze())
+            with self.raises(s_exc.SynErr) as cm:
+                await prox.raze()
+            self.eq(cm.exception.get('mesg'), 'hehe')
+            self.eq(cm.exception.get('key'), 'valu')
 
-            await self.asyncraises(s_exc.NoSuchMeth, prox.fake())
+            with self.raises(s_exc.NoSuchMeth) as cm:
+                await prox.fake()
+            self.eq(cm.exception.get('mesg'), 'Foo has no method: fake.')
+            self.eq(cm.exception.get('name'), 'fake')
 
-            await self.asyncraises(s_exc.SynErr, prox.boom())
+            with self.raises(s_exc.NoSuchMeth) as cm:
+                await prox._fake()
+            self.eq(cm.exception.get('mesg'), 'Foo has no method: _fake.')
+            self.eq(cm.exception.get('name'), '_fake')
+
+            with self.raises(s_exc.NotMsgpackSafe) as cm:
+                await prox.boom()
+            self.isin("can not serialize 'Boom' object", cm.exception.get('mesg'))
 
         # Fini'ing a daemon fini's proxies connected to it.
         self.true(await s_coro.event_wait(evt, 2))
         self.true(prox.isfini)
         await self.asyncraises(s_exc.IsFini, prox.bar((10, 20)))
 
+    async def test_telepath_openinfo_cell(self):
+        with self.getTestDir() as dirn:
+            async with self.getTestCore(dirn=dirn) as core:
+
+                layr00 = core.getView().layers[0]
+
+                async with await s_telepath.openurl(f'cell://root@{dirn}:*', name=f'*/layer/{layr00.iden}') as layer:
+                    self.eq(layr00.iden, await layer.getIden())
+
+    async def test_telepath_openinfo_unix(self):
+        with self.getTestDir() as dirn:
+            async with self.getTestCore(dirn=dirn) as core:
+
+                layr00 = core.getView().layers[0]
+
+                async with await s_telepath.openurl(f'unix://root@{dirn}/sock:*', name=f'*/layer/{layr00.iden}') as layer:
+                    self.eq(layr00.iden, await layer.getIden())
+
     async def test_telepath_sync_genr(self):
 
         foo = Foo()
@@ -279,43 +361,20 @@ class TeleTest(s_t_utils.SynTest):
             async with await s_telepath.openurl('tcp://127.0.0.1/foo', port=dmon.addr[1]) as prox:
                 self.eq((10, 20, 30), await s_coro.executor(sync))
 
-    def test_telepath_sync_genr_break(self):
+    async def test_telepath_sync_genr_break(self):
+        async with self.getTestCore() as core:
+            url = core.getLocalUrl()
 
-        try:
-            acm = self.getTestCoreAndProxy()
-            core, proxy = s_glob.sync(acm.__aenter__())
+            ctx = multiprocessing.get_context('spawn')
+            evt1 = ctx.Event()
+            evt2 = ctx.Event()
+            proc = ctx.Process(target=run_telepath_sync_genr_break, args=(url, evt1, evt2))
+            proc.start()
 
-            form = 'test:int'
-
-            q = '[' + ' '.join([f'{form}={i}' for i in range(10)]) + ' ]'
-
-            # This puts a link into the link pool
-            msgs = list(proxy.storm(q, opts={'show': ('node',)}))
-            self.len(12, msgs)
-
-            evt = threading.Event()
-
-            # Get the link from the pool, add the fini callback and put it back
-            link = s_glob.sync(proxy.getPoolLink())
-            link.onfini(evt.set)
-            s_glob.sync(proxy._putPoolLink(link))
-
-            q = f'{form} | sleep 0.1'
-
-            # Break from the generator right away, causing a
-            # GeneratorExit in the GenrHelp object __iter__ method.
-            mesg = None
-            for mesg in proxy.storm(q):
-                break
-            # Ensure the query did yield an object
-            self.nn(mesg)
-
-            # Ensure the link we have a reference too was torn down
-            self.true(evt.wait(4))
-            self.true(link.isfini)
-
-        finally:
-            s_glob.sync(acm.__aexit__(None, None, None))
+            self.true(await s_coro.executor(evt1.wait, timeout=30))
+            self.true(await s_coro.executor(evt2.wait, timeout=30))
+            proc.join(timeout=30)
+            self.eq(proc.exitcode, 137)
 
     async def test_telepath_no_sess(self):
 
@@ -349,10 +408,12 @@ class TeleTest(s_t_utils.SynTest):
                 genr = prox.corogenr(3)
                 self.eq((0, 1, 2), await s_t_utils.alist(genr))
 
-                await self.asyncraises(s_exc.NoSuchMeth, prox.raze())
+                await self.asyncraises(s_exc.SynErr, prox.raze())
 
                 await self.asyncraises(s_exc.NoSuchMeth, prox.fake())
 
+                await self.asyncraises(s_exc.NoSuchMeth, prox._fake())
+
                 await self.asyncraises(s_exc.SynErr, prox.boom())
 
             # Fini'ing a daemon fini's proxies connected to it.
@@ -625,7 +686,15 @@ class TeleTest(s_t_utils.SynTest):
                 self.len(1, snfo)
                 self.eq(snfo[0].get('items'), {None: 'synapse.tests.test_telepath.TeleApi'})
 
+                self.true(proxy._hasTeleFeat('aware'))
+                self.false(proxy._hasTeleFeat('aware', vers=2))
+                self.false(proxy._hasTeleFeat('newp'))
+
+                self.true(proxy._hasTeleMeth('getFooBar'))
+                self.false(proxy._hasTeleMeth('getBarBaz'))
+
                 self.eq(10, await proxy.getFooBar(20, 10))
+                self.eq([10], [m async for m in await proxy.genGetFooBar(20, 10)])
 
                 # check a custom share works
                 obj = await proxy.customshare()
@@ -667,7 +736,14 @@ class TeleTest(s_t_utils.SynTest):
 
             # check that a dynamic share works
             async with await self.getTestProxy(dmon, 'woke/up') as proxy:
+                self.isin('synapse.tests.test_telepath.Beep', proxy._getClasses())
+                self.notin('synapse.tests.test_telepath.TeleApi', proxy._getClasses())
                 self.eq('up: beep', await proxy.beep())
+                self.eq(['up: beep'], [m async for m in await proxy.genbeep()])
+                # Telepath features are a function of the base object, not the result of getTeleApi
+                self.true(proxy._hasTeleFeat('aware'))
+                self.false(proxy._hasTeleFeat('aware', vers=2))
+                self.false(proxy._hasTeleFeat('newp'))
 
     async def test_telepath_auth(self):
 
@@ -773,6 +849,18 @@ class TeleTest(s_t_utils.SynTest):
                             {'family': 'unix',
                              'addr': sockpath})
 
+    async def test_url_bad_cell_path(self):
+        with self.getTestDir() as dirn:
+            # Touch the sock path
+            s_common.genfile(dirn, 'newp', 'sock').close()
+            cell_url = f'cell://{dirn}/newp'
+            with self.raises(s_exc.LinkErr) as cm:
+                await s_telepath.openurl(cell_url)
+            self.isin('Cell path is not listening', cm.exception.get('mesg'))
+        with self.raises(s_exc.NoSuchPath) as cm:
+            await s_telepath.openurl(cell_url)
+        self.isin('Cell path does not exist', cm.exception.get('mesg'))
+
     async def test_ipv6(self):
         if s_common.envbool('CIRCLECI'):
             self.skip('ipv6 listener is not supported in circleci')
@@ -902,7 +990,6 @@ class TeleTest(s_t_utils.SynTest):
 
             # Validate the Proxy behavior then the client override
             prox = await s_telepath.openurl(url)  # type: Foo
-            prox._link_poolsize = 2
 
             # Start with no links
             self.len(0, prox.links)
@@ -914,53 +1001,76 @@ class TeleTest(s_t_utils.SynTest):
             genr = await prox.genr()  # type: s_coro.GenrHelp
             self.eq(await genr.genr.__anext__(), 10)
 
-            # The link is being used by the genr
-            self.len(0, prox.links)
+            # A new link is in the pool
+            self.len(1, prox.links)
 
-            # and upon exhuastion, that link is put back
+            # and upon exhuastion, the first link is put back
             self.eq(await genr.list(), (20, 30))
-            self.len(1, prox.links)
-            self.true(prox.links[0] is l0)
+            self.len(2, prox.links)
+            self.true(prox.links[1] is l0)
+
+            # Grabbing a link will still spin up another since we are below low watermark
+            genr = await prox.genr()  # type: s_coro.GenrHelp
+            self.eq(await genr.genr.__anext__(), 10)
 
-            # Grab the existing link, then do two more calls
-            genr0 = await prox.genr()  # contains l0
-            genr1 = await prox.genr()
-            genr2 = await prox.genr()
-            self.len(0, prox.links)
-            # Consume two of the three generators
-            self.eq(await genr2.list(), (10, 20, 30))
-            self.len(1, prox.links)
-            self.eq(await genr1.list(), (10, 20, 30))
             self.len(2, prox.links)
-            # Exhausting the lsat generator results in his
-            # link not being placed back into the pool
-            self.eq(await genr0.list(), (10, 20, 30))
-            self.len(2, prox.links)
-            links = set(lnk for lnk in prox.links)
-            self.notin(l0, links)
-            # And that link l0 has been fini'd
-            self.true(l0.isfini)
+
+            self.eq(await genr.list(), (20, 30))
+            self.len(3, prox.links)
+
+            # Fill up pool above low watermark
+            genrs = [await prox.genr() for _ in range(2)]
+            [await genr.list() for genr in genrs]
+            self.len(5, prox.links)
+
+            # Grabbing a link no longer spins up a replacement
+            genr = await prox.genr()  # type: s_coro.GenrHelp
+            self.eq(await genr.genr.__anext__(), 10)
+            self.len(4, prox.links)
+
+            self.eq(await genr.list(), (20, 30))
+            self.len(5, prox.links)
 
             # Tear down a link by hand and place it back
             # into the pool - that will fail b/c the link
             # has been down down.
             l1 = await prox.getPoolLink()
-            self.len(1, prox.links)
+            self.len(4, prox.links)
             await l1.fini()
             await prox._putPoolLink(l1)
-            self.len(1, prox.links)
+            self.len(4, prox.links)
 
             # And all our links are torn down on fini
             await prox.fini()
-            self.len(1, prox.links)
-            for link in prox.links:
-                self.true(link.isfini)
+            self.len(4, prox.links)
+            for link in list(prox.links):
+                self.true(await link.waitfini(1))
+            self.len(0, prox.links)
 
-            # The telepath Client passes through this value as a configuration parameter
-            conf = {'link_poolsize': 2, 'timeout': 2}
-            async with await s_telepath.Client.anit(url, conf=conf) as client:
-                await client.waitready()
-                self.true(client._t_proxy._link_poolsize, 2)
+        with mock.patch('synapse.telepath.LINK_CULL_INTERVAL', 1):
+            async with self.getTestDmon() as dmon:
+                dmon.share('foo', foo)
+                url = f'tcp://127.0.0.1:{dmon.addr[1]}/foo'
+
+                prox = await s_telepath.openurl(url)
+
+                # Fill up pool above high watermark
+                genrs = [await prox.genr() for _ in range(13)]
+                [await genr.list() for genr in genrs]
+                self.len(13, prox.links)
+
+                # Add a fini'd proxy for coverage
+                prox2 = await s_telepath.openurl(url)
+                await prox2.fini()
+                prox2._all_proxies.add(prox2)
+
+                wait = prox.waiter(1, 'pool:link:fini')
+                self.len(1, await wait.wait(timeout=5))
+                self.len(12, prox.links)
+
+                # Cleanup our global state
+                prox2._all_proxies.remove(prox2)
+                await prox.fini()
 
     async def test_link_fini_breaking_tasks(self):
         foo = Foo()
@@ -1029,7 +1139,7 @@ class TeleTest(s_t_utils.SynTest):
 
                 self.eq(vals, (40, 50, 60))
 
-                self.eq(1, len(proxy.links))
+                self.eq(2, len(proxy.links))
                 self.eq(160, await proxy.bar(80, 80))
 
                 async def boomgenr():
@@ -1227,7 +1337,7 @@ class TeleTest(s_t_utils.SynTest):
                 self.isin('synapse.tests.test_telepath.Foo', proxy._getClasses())
                 self.eq(await proxy.echo('oh hi mark!'), 'oh hi mark!')
 
-    async def test_tls_ciphers(self):
+    async def test_tls_support_and_ciphers(self):
 
         self.thisHostMustNot(platform='darwin')
 
@@ -1249,6 +1359,18 @@ class TeleTest(s_t_utils.SynTest):
             async with await s_telepath.openurl(f'ssl://{hostname}/foo', port=port) as prox:
                 self.eq(30, await prox.bar(10, 20))
 
+                # This will generate a large msgpack object which can cause
+                # openssl to have malloc failures. Prior to the write chunking
+                # changes, this would cause a generally fatal error to any
+                # processes which rely on the calls work, such as mirror loops.
+                blob = b'V' * s_const.mebibyte * 256
+                nblobs = 8
+                total = nblobs * len(blob)
+                blobarray = []
+                for i in range(nblobs):
+                    blobarray.append(blob)
+                self.eq(await prox.echosize(blobarray), total)
+
             sslctx = ssl.SSLContext(protocol=ssl.PROTOCOL_TLSv1)
             with self.raises((ssl.SSLError, ConnectionResetError)):
                 link = await s_link.connect(hostname, port=port, ssl=sslctx)
