@@ -1,4 +1,3 @@
-import json
 import hashlib
 
 from unittest import mock
@@ -6,6 +5,7 @@ from unittest import mock
 import synapse.exc as s_exc
 import synapse.common as s_common
 
+import synapse.lib.json as s_json
 import synapse.lib.msgpack as s_msgpack
 
 import synapse.tools.feed as s_feed
@@ -33,7 +33,7 @@ class FeedTest(s_t_utils.SynTest):
                 with s_common.genfile(jsonlfp) as fd:
                     for i in range(20):
                         pode = (('test:int', i), {})
-                        _ = fd.write(json.dumps(pode).encode() + b'\n')
+                        _ = fd.write(s_json.dumps(pode, newline=True))
 
                 argv = ['--cortex', curl,
                         '--format', 'syn.nodes',
@@ -138,3 +138,31 @@ class FeedTest(s_t_utils.SynTest):
 
             nodes = await core.nodes('test:int', opts={'view': oldview})
             self.len(0, nodes)
+
+    async def test_synnodes_json(self):
+        async with self.getTestCore() as core:
+
+            await self.addCreatorDeleterRoles(core)
+
+            host, port = await core.dmon.listen('tcp://127.0.0.1:0/')
+
+            curl = f'tcp://icanadd:secret@{host}:{port}/'
+
+            with self.getTestDir() as dirn:
+
+                jsonfp = s_common.genpath(dirn, 'podes.json')
+                with s_common.genfile(jsonfp) as fd:
+                    podes = [(('test:int', ii), {}) for ii in range(20)]
+                    s_json.dump(podes, fd)
+
+                argv = ['--cortex', curl,
+                        '--format', 'syn.nodes',
+                        '--modules', 'synapse.tests.utils.TestModule',
+                        '--chunksize', '3',
+                        jsonfp]
+
+                outp = self.getTestOutp()
+                self.eq(await s_feed.main(argv, outp=outp), 0)
+
+            nodes = await core.nodes('test:int')
+            self.len(20, nodes)
