@@ -21,13 +21,11 @@ import io
 import os
 import sys
 import copy
-import json
 import math
 import types
 import shutil
 import typing
 import asyncio
-import hashlib
 import inspect
 import logging
 import tempfile
@@ -59,6 +57,7 @@ import synapse.lib.cell as s_cell
 import synapse.lib.coro as s_coro
 import synapse.lib.cmdr as s_cmdr
 import synapse.lib.hive as s_hive
+import synapse.lib.json as s_json
 import synapse.lib.task as s_task
 import synapse.lib.const as s_const
 import synapse.lib.layer as s_layer
@@ -101,7 +100,7 @@ def deguidify(x):
 
 def jsonlines(text: str):
     lines = [k for k in text.split('\n') if k]
-    return [json.loads(line) for line in lines]
+    return [s_json.loads(line) for line in lines]
 
 async def waitForBehold(core, events):
     async for mesg in core.behold():
@@ -318,6 +317,7 @@ testmodel = {
         ('test:int', ('int', {}), {}),
         ('test:float', ('float', {}), {}),
         ('test:str', ('str', {}), {}),
+        ('test:strregex', ('str', {'lower': True, 'strip': True, 'regex': r'^#[^\p{Z}#]+$'}), {}),
         ('test:migr', ('str', {}), {}),
         ('test:auto', ('str', {}), {}),
         ('test:edge', ('edge', {}), {}),
@@ -341,10 +341,10 @@ testmodel = {
             ('foo', 'test:int'),
             ('bar', ('str', {'lower': True}),),
         )}), {'doc': 'A complex comp type.'}),
-        ('test:hexa', ('hex', {}), {'doc': 'anysize test hex type'}),
-        ('test:hex4', ('hex', {'size': 4}), {'doc': 'size 4 test hex type'}),
-        ('test:hexpad', ('hex', {'size': 8, 'zeropad': True}), {'doc': 'size 8 test hex type, zero padded'}),
-        ('test:zeropad', ('hex', {'zeropad': 20}), {'doc': 'test hex type, zero padded to 40 bytes'}),
+        ('test:hexa', ('hex', {}), {'doc': 'anysize test hex type.'}),
+        ('test:hex4', ('hex', {'size': 4}), {'doc': 'size 4 test hex type.'}),
+        ('test:hexpad', ('hex', {'size': 8, 'zeropad': True}), {'doc': 'size 8 test hex type, zero padded.'}),
+        ('test:zeropad', ('hex', {'zeropad': 20}), {'doc': 'test hex type, zero padded to 40 bytes.'}),
 
         ('test:pivtarg', ('str', {}), {}),
         ('test:pivcomp', ('comp', {'fields': (('targ', 'test:pivtarg'), ('lulz', 'test:str'))}), {}),
@@ -365,7 +365,7 @@ testmodel = {
             'interfaces': ('file:mime:msoffice',)
         }), {}),
 
-        ('test:runt', ('str', {'lower': True, 'strip': True}), {'doc': 'A Test runt node'}),
+        ('test:runt', ('str', {'lower': True, 'strip': True}), {'doc': 'A Test runt node.'}),
         ('test:hasiface', ('str', {}), {'interfaces': ('test:interface',)}),
         ('test:hasiface2', ('str', {}), {'interfaces': ('test:interface',)}),
     ),
@@ -381,6 +381,7 @@ testmodel = {
             ('ints', ('array', {'type': 'test:int'}), {}),
             ('strs', ('array', {'type': 'test:str', 'split': ','}), {}),
             ('strsnosplit', ('array', {'type': 'test:str'}), {}),
+            ('strregexs', ('array', {'type': 'test:strregex', 'uniq': True, 'sorted': True}), {}),
         )),
         ('test:arrayform', {}, (
         )),
@@ -438,6 +439,7 @@ testmodel = {
 
         ('test:guid', {}, (
             ('size', ('test:int', {}), {}),
+            ('name', ('test:str', {}), {}),
             ('tick', ('test:time', {}), {}),
             ('posneg', ('test:sub', {}), {}),
             ('posneg:isbig', ('bool', {}), {}),
@@ -457,7 +459,10 @@ testmodel = {
             ('tick', ('test:time', {}), {}),
             ('hehe', ('str', {}), {}),
             ('ndefs', ('array', {'type': 'ndef'}), {}),
+            ('somestr', ('test:str', {}), {}),
+            ('gprop', ('test:guid', {}), {}),
         )),
+        ('test:strregex', {}, ()),
 
         ('test:migr', {}, (
             ('bar', ('ndef', {}), {}),
@@ -503,8 +508,8 @@ testmodel = {
         )),
 
         ('test:ro', {}, (
-            ('writeable', ('str', {}), {'doc': 'writeable property'}),
-            ('readable', ('str', {}), {'doc': 'ro property', 'ro': True}),
+            ('writeable', ('str', {}), {'doc': 'writeable property.'}),
+            ('readable', ('str', {}), {'doc': 'ro property.', 'ro': True}),
         )),
 
         ('test:hasiface', {}, ()),
@@ -519,6 +524,12 @@ deprmodel = {
         ('test:deprarray', ('array', {'type': 'test:deprprop'}), {}),
         ('test:deprform', ('test:str', {}), {}),
         ('test:deprndef', ('ndef', {}), {}),
+        ('test:deprsub', ('str', {}), {}),
+        ('test:range', ('range', {}), {}),
+        ('test:deprsub2', ('comp', {'fields': (
+            ('name', 'test:str'),
+            ('range', 'test:range'))
+        }), {}),
     ),
     'forms': (
         ('test:deprprop', {}, ()),
@@ -527,6 +538,17 @@ deprmodel = {
             ('deprprop', ('test:deprarray', {}), {}),
             ('okayprop', ('str', {}), {}),
         )),
+        ('test:deprsub', {}, (
+            ('range', ('test:range', {}), {}),
+            ('range:min', ('int', {}), {'deprecated': True}),
+            ('range:max', ('int', {}), {}),
+        )),
+        ('test:deprsub2', {}, (
+            ('name', ('str', {}), {}),
+            ('range', ('test:range', {}), {}),
+            ('range:min', ('int', {}), {}),
+            ('range:max', ('int', {}), {'deprecated': True}),
+        )),
     ),
 
 }
@@ -768,14 +790,9 @@ class CmdGenerator:
 
         return retn
 
-class StreamEvent(io.StringIO, threading.Event):
-    '''
-    A combination of a io.StringIO object and a threading.Event object.
-    '''
+class _StreamIOMixin(io.StringIO):
     def __init__(self, *args, **kwargs):
         io.StringIO.__init__(self, *args, **kwargs)
-        threading.Event.__init__(self)
-        self.mesg = ''
 
     def setMesg(self, mesg):
         '''
@@ -790,6 +807,9 @@ class StreamEvent(io.StringIO, threading.Event):
         self.mesg = mesg
         self.clear()
 
+    def __str__(self):
+        return self.getvalue()
+
     def write(self, s):
         io.StringIO.write(self, s)
         if self.mesg and self.mesg in s:
@@ -799,42 +819,59 @@ class StreamEvent(io.StringIO, threading.Event):
         '''Get the messages as jsonlines. May throw Json errors if the captured stream is not jsonlines.'''
         return jsonlines(self.getvalue())
 
-class AsyncStreamEvent(io.StringIO, asyncio.Event):
+    def expect(self, substr: str):
+        '''
+        Check if a string is present in the messages captured by StreamEvent.
+
+        Args:
+            substr (str): String to check for the existence of.
+        '''
+        valu = self.getvalue()
+        if valu.find(substr) == -1:
+            mesg = '%s.expect(%s) not in %s' % (self.__class__.__name__, substr, valu)
+            raise s_exc.SynErr(mesg=mesg)
+
+class StreamEvent(_StreamIOMixin, threading.Event):
+    '''
+    A combination of a io.StringIO object and a threading.Event object.
+    '''
+    def __init__(self, *args, **kwargs):
+        _StreamIOMixin.__init__(self, *args, **kwargs)
+        threading.Event.__init__(self)
+        self.mesg = ''
+
+    def __repr__(self):
+        cls = self.__class__
+        status = 'set' if self._flag else 'unset'
+        if valu := str(self):
+            valu = s_common.trimText(valu).strip()
+            status = f'{status}, valu: {valu}'
+        return f"<{cls.__module__}.{cls.__qualname__} at {id(self):#x}: {status}>"
+
+class AsyncStreamEvent(_StreamIOMixin, asyncio.Event):
     '''
     A combination of a io.StringIO object and an asyncio.Event object.
     '''
     def __init__(self, *args, **kwargs):
-        io.StringIO.__init__(self, *args, **kwargs)
+        _StreamIOMixin.__init__(self, *args, **kwargs)
         asyncio.Event.__init__(self)
         self.mesg = ''
 
-    def setMesg(self, mesg):
-        '''
-        Clear the internal event and set a new message that is used to set the event.
-
-        Args:
-            mesg (str): The string to monitor for.
-
-        Returns:
-            None
-        '''
-        self.mesg = mesg
-        self.clear()
-
-    def write(self, s):
-        io.StringIO.write(self, s)
-        if self.mesg and self.mesg in s:
-            self.set()
+    def __repr__(self):
+        cls = self.__class__
+        status = 'set' if self._value else 'unset'
+        if self._waiters:
+            status = f'{status}, waiters:{len(self._waiters)}'
+        if valu := str(self):
+            valu = s_common.trimText(valu).strip()
+            status = f'{status}, valu: {valu}'
+        return f"<{cls.__module__}.{cls.__qualname__} at {id(self):#x}: {status}>"
 
     async def wait(self, timeout=None):
         if timeout is None:
             return await asyncio.Event.wait(self)
         return await s_coro.event_wait(self, timeout=timeout)
 
-    def jsonlines(self) -> typing.List[dict]:
-        '''Get the messages as jsonlines. May throw Json errors if the captured stream is not jsonlines.'''
-        return jsonlines(self.getvalue())
-
 class HttpReflector(s_httpapi.Handler):
     '''Test handler which reflects get/post data back to the caller'''
 
@@ -844,7 +881,7 @@ class HttpReflector(s_httpapi.Handler):
             for k, items in self.request.arguments.items():
                 for v in items:
                     d[k].append(v.decode())
-        return d
+        return dict(d)
 
     async def get(self):
         resp = {}
@@ -967,6 +1004,10 @@ test_schema = {
                 'description': 'Foo String',
                 'type': 'string',
             },
+            'key:multi': {
+                'description': 'String or integer',
+                'type': ['string', 'integer'],
+            }
         },
         'type': 'object',
     }
@@ -1005,8 +1046,6 @@ class SynTest(unittest.TestCase):
     '''
     def __init__(self, *args, **kwargs):
         unittest.TestCase.__init__(self, *args, **kwargs)
-        self._NextBuid = 0
-        self._NextGuid = 0
 
         for s in dir(self):
             attr = getattr(self, s, None)
@@ -2358,58 +2397,6 @@ class SynTest(unittest.TestCase):
             async with await s_hive.SlabHive.anit(slab) as hive:
                 yield hive
 
-    @contextlib.asynccontextmanager
-    async def getTestHiveDmon(self):
-        with self.getTestDir() as dirn:
-            async with self.getTestHiveFromDirn(dirn) as hive:
-                async with self.getTestDmon() as dmon:
-                    dmon.share('hive', hive)
-                    yield dmon
-
-    @contextlib.asynccontextmanager
-    async def getTestTeleHive(self):
-
-        async with self.getTestHiveDmon() as dmon:
-
-            turl = self.getTestUrl(dmon, 'hive')
-
-            async with await s_hive.openurl(turl) as hive:
-
-                yield hive
-
-    def stablebuid(self, valu=None):
-        '''
-        A stable buid generation for testing purposes
-        '''
-        if valu is None:
-            retn = self._NextBuid.to_bytes(32, 'big')
-            self._NextBuid += 1
-            return retn
-
-        byts = s_msgpack.en(valu)
-        return hashlib.sha256(byts).digest()
-
-    def stableguid(self, valu=None):
-        '''
-        A stable guid generation for testing purposes
-        '''
-        if valu is None:
-            retn = s_common.ehex(self._NextGuid.to_bytes(16, 'big'))
-            self._NextGuid += 1
-            return retn
-
-        byts = s_msgpack.en(valu)
-        return hashlib.md5(byts, usedforsecurity=False).hexdigest()
-
-    @contextlib.contextmanager
-    def withStableUids(self):
-        '''
-        A context manager that generates guids and buids in sequence so that successive test runs use the same
-        data
-        '''
-        with mock.patch('synapse.common.guid', self.stableguid), mock.patch('synapse.common.buid', self.stablebuid):
-            yield
-
     async def runCoreNodes(self, core, query, opts=None):
         '''
         Run a storm query through a Cortex as a SchedCoro and return the results.
