@@ -1,5 +1,3 @@
-import sys
-import json
 import socket
 import asyncio
 
@@ -8,13 +6,13 @@ import synapse.common as s_common
 import synapse.telepath as s_telepath
 
 import synapse.lib.cmd as s_cmd
+import synapse.lib.json as s_json
 import synapse.lib.output as s_output
 import synapse.lib.health as s_health
 import synapse.lib.urlhelp as s_urlhelp
 
 def serialize(ret):
-    s = json.dumps(ret, separators=(',', ':'))
-    return s
+    return s_json.dumps(ret).decode()
 
 def format_component(e, mesg: str) -> dict:
     d = {
@@ -30,7 +28,7 @@ def format_component(e, mesg: str) -> dict:
     return d
 
 async def main(argv, outp=s_output.stdout):
-    pars = makeargparser()
+    pars = getArgParser(outp)
     try:
         opts = pars.parse_args(argv)
     except s_exc.ParserExit as e:  # pragma: no cover
@@ -44,7 +42,7 @@ async def main(argv, outp=s_output.stdout):
 
             prox = await s_common.wait_for(s_telepath.openurl(url),
                                            timeout=opts.timeout)
-    except (FileNotFoundError, ConnectionError, socket.gaierror) as e:
+    except (s_exc.LinkErr, s_exc.NoSuchPath, socket.gaierror) as e:
         mesg = f'Unable to connect to cell @ {sanitized_url}.'
         ret = {'status': 'failed',
                'iden': opts.cell,
@@ -96,11 +94,11 @@ async def main(argv, outp=s_output.stdout):
     outp.printf(serialize(ret))
     return retval
 
-def makeargparser():
+def getArgParser(outp):
     desc = '''
     synapse healthcheck tool
     '''
-    pars = s_cmd.Parser('healthcheck', description=desc)
+    pars = s_cmd.Parser(prog='synapse.tools.healthcheck', outp=outp, description=desc)
     pars.add_argument('--cell', '-c', required=True, type=str,
                       help='Telepath path to the cell to check.')
     pars.add_argument('--timeout', '-t', default=10, type=float,
@@ -108,4 +106,4 @@ def makeargparser():
     return pars
 
 if __name__ == '__main__':  # pragma: no cover
-    sys.exit(asyncio.run(main(sys.argv[1:])))
+    s_cmd.exitmain(main)
